@@ -5,6 +5,9 @@ Entry point for package.
 See, e.g., https://docs.python.org/3/library/__main__.html#main-py-in-python-packages
 """
 
+import sys
+
+
 # Note the the following import appears not to work if you attempt to run my_module.py directly
 # with `python src/demo_package_sample_data_with_code/my_module.py`, returning the following error:
 #     ImportError: attempted relative import with no known parent package
@@ -12,4 +15,4 @@ See, e.g., https://docs.python.org/3/library/__main__.html#main-py-in-python-pac
 from . my_module import main
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    sys.exit(main())
\ No newline at end of file
